/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import * as beet from '@metaplex-foundation/beet';
import { AccountType } from '../types/AccountType';
export declare type PackCardArgs = {
    accountType: AccountType;
    packSet: web3.PublicKey;
    master: web3.PublicKey;
    metadata: web3.PublicKey;
    tokenAccount: web3.PublicKey;
    maxSupply: number;
    weight: number;
};
export declare class PackCard implements PackCardArgs {
    readonly accountType: AccountType;
    readonly packSet: web3.PublicKey;
    readonly master: web3.PublicKey;
    readonly metadata: web3.PublicKey;
    readonly tokenAccount: web3.PublicKey;
    readonly maxSupply: number;
    readonly weight: number;
    private constructor();
    static fromArgs(args: PackCardArgs): PackCard;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [PackCard, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<PackCard>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<{
        accountType: any;
        packSet: any;
        master: any;
        metadata: any;
        tokenAccount: any;
        maxSupply: any;
        weight: any;
    }>;
    static deserialize(buf: Buffer, offset?: number): [PackCard, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        accountType: string;
        packSet: string;
        master: string;
        metadata: string;
        tokenAccount: string;
        maxSupply: number;
        weight: number;
    };
}
export declare const packCardBeet: beet.BeetStruct<PackCard, PackCardArgs>;
