/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import { AccountType } from '../types/AccountType';
import { PackSetState } from '../types/PackSetState';
import { PackDistributionType } from '../types/PackDistributionType';
export declare type PackSetArgs = {
    accountType: AccountType;
    store: web3.PublicKey;
    authority: web3.PublicKey;
    description: string;
    uri: string;
    name: number[];
    packCards: number;
    packVouchers: number;
    totalWeight: beet.bignum;
    totalEditions: beet.bignum;
    mutable: boolean;
    packState: PackSetState;
    distributionType: PackDistributionType;
    allowedAmountToRedeem: number;
    redeemStartDate: beet.bignum;
    redeemEndDate: beet.COption<beet.bignum>;
};
export declare class PackSet implements PackSetArgs {
    readonly accountType: AccountType;
    readonly store: web3.PublicKey;
    readonly authority: web3.PublicKey;
    readonly description: string;
    readonly uri: string;
    readonly name: number[];
    readonly packCards: number;
    readonly packVouchers: number;
    readonly totalWeight: beet.bignum;
    readonly totalEditions: beet.bignum;
    readonly mutable: boolean;
    readonly packState: PackSetState;
    readonly distributionType: PackDistributionType;
    readonly allowedAmountToRedeem: number;
    readonly redeemStartDate: beet.bignum;
    readonly redeemEndDate: beet.COption<beet.bignum>;
    private constructor();
    static fromArgs(args: PackSetArgs): PackSet;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [PackSet, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<PackSet>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<{
        accountType: any;
        store: any;
        authority: any;
        description: any;
        uri: any;
        name: any;
        packCards: any;
        packVouchers: any;
        totalWeight: any;
        totalEditions: any;
        mutable: any;
        packState: any;
        distributionType: any;
        allowedAmountToRedeem: any;
        redeemStartDate: any;
        redeemEndDate: any;
    }>;
    static deserialize(buf: Buffer, offset?: number): [PackSet, number];
    serialize(): [Buffer, number];
    static byteSize(args: PackSetArgs): number;
    static getMinimumBalanceForRentExemption(args: PackSetArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        accountType: string;
        store: string;
        authority: string;
        description: string;
        uri: string;
        name: number[];
        packCards: number;
        packVouchers: number;
        totalWeight: number | {
            toNumber: () => number;
        };
        totalEditions: number | {
            toNumber: () => number;
        };
        mutable: boolean;
        packState: string;
        distributionType: string;
        allowedAmountToRedeem: number;
        redeemStartDate: number | {
            toNumber: () => number;
        };
        redeemEndDate: beet.bignum;
    };
}
export declare const packSetBeet: beet.FixableBeetStruct<PackSet, PackSetArgs>;
