"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.packSetBeet = exports.PackSet = void 0;
const web3 = __importStar(require("@solana/web3.js"));
const beet = __importStar(require("@metaplex-foundation/beet"));
const beetSolana = __importStar(require("@metaplex-foundation/beet-solana"));
const AccountType_1 = require("../types/AccountType");
const PackSetState_1 = require("../types/PackSetState");
const PackDistributionType_1 = require("../types/PackDistributionType");
class PackSet {
    constructor(accountType, store, authority, description, uri, name, packCards, packVouchers, totalWeight, totalEditions, mutable, packState, distributionType, allowedAmountToRedeem, redeemStartDate, redeemEndDate) {
        this.accountType = accountType;
        this.store = store;
        this.authority = authority;
        this.description = description;
        this.uri = uri;
        this.name = name;
        this.packCards = packCards;
        this.packVouchers = packVouchers;
        this.totalWeight = totalWeight;
        this.totalEditions = totalEditions;
        this.mutable = mutable;
        this.packState = packState;
        this.distributionType = distributionType;
        this.allowedAmountToRedeem = allowedAmountToRedeem;
        this.redeemStartDate = redeemStartDate;
        this.redeemEndDate = redeemEndDate;
    }
    static fromArgs(args) {
        return new PackSet(args.accountType, args.store, args.authority, args.description, args.uri, args.name, args.packCards, args.packVouchers, args.totalWeight, args.totalEditions, args.mutable, args.packState, args.distributionType, args.allowedAmountToRedeem, args.redeemStartDate, args.redeemEndDate);
    }
    static fromAccountInfo(accountInfo, offset = 0) {
        return PackSet.deserialize(accountInfo.data, offset);
    }
    static async fromAccountAddress(connection, address) {
        const accountInfo = await connection.getAccountInfo(address);
        if (accountInfo == null) {
            throw new Error(`Unable to find PackSet account at ${address}`);
        }
        return PackSet.fromAccountInfo(accountInfo, 0)[0];
    }
    static gpaBuilder(programId = new web3.PublicKey('packFeFNZzMfD9aVWL7QbGz1WcU7R9zpf6pvNsw2BLu')) {
        return beetSolana.GpaBuilder.fromStruct(programId, exports.packSetBeet);
    }
    static deserialize(buf, offset = 0) {
        return exports.packSetBeet.deserialize(buf, offset);
    }
    serialize() {
        return exports.packSetBeet.serialize(this);
    }
    static byteSize(args) {
        const instance = PackSet.fromArgs(args);
        return exports.packSetBeet.toFixedFromValue(instance).byteSize;
    }
    static async getMinimumBalanceForRentExemption(args, connection, commitment) {
        return connection.getMinimumBalanceForRentExemption(PackSet.byteSize(args), commitment);
    }
    pretty() {
        return {
            accountType: 'AccountType.' + AccountType_1.AccountType[this.accountType],
            store: this.store.toBase58(),
            authority: this.authority.toBase58(),
            description: this.description,
            uri: this.uri,
            name: this.name,
            packCards: this.packCards,
            packVouchers: this.packVouchers,
            totalWeight: (() => {
                const x = this.totalWeight;
                if (typeof x.toNumber === 'function') {
                    try {
                        return x.toNumber();
                    }
                    catch (_) {
                        return x;
                    }
                }
                return x;
            })(),
            totalEditions: (() => {
                const x = this.totalEditions;
                if (typeof x.toNumber === 'function') {
                    try {
                        return x.toNumber();
                    }
                    catch (_) {
                        return x;
                    }
                }
                return x;
            })(),
            mutable: this.mutable,
            packState: 'PackSetState.' + PackSetState_1.PackSetState[this.packState],
            distributionType: 'PackDistributionType.' + PackDistributionType_1.PackDistributionType[this.distributionType],
            allowedAmountToRedeem: this.allowedAmountToRedeem,
            redeemStartDate: (() => {
                const x = this.redeemStartDate;
                if (typeof x.toNumber === 'function') {
                    try {
                        return x.toNumber();
                    }
                    catch (_) {
                        return x;
                    }
                }
                return x;
            })(),
            redeemEndDate: this.redeemEndDate,
        };
    }
}
exports.PackSet = PackSet;
exports.packSetBeet = new beet.FixableBeetStruct([
    ['accountType', AccountType_1.accountTypeBeet],
    ['store', beetSolana.publicKey],
    ['authority', beetSolana.publicKey],
    ['description', beet.utf8String],
    ['uri', beet.utf8String],
    ['name', beet.uniformFixedSizeArray(beet.u8, 32)],
    ['packCards', beet.u32],
    ['packVouchers', beet.u32],
    ['totalWeight', beet.u64],
    ['totalEditions', beet.u64],
    ['mutable', beet.bool],
    ['packState', PackSetState_1.packSetStateBeet],
    ['distributionType', PackDistributionType_1.packDistributionTypeBeet],
    ['allowedAmountToRedeem', beet.u32],
    ['redeemStartDate', beet.u64],
    ['redeemEndDate', beet.coption(beet.u64)],
], PackSet.fromArgs, 'PackSet');
//# sourceMappingURL=PackSet.js.map