/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import * as beet from '@metaplex-foundation/beet';
import { AccountType } from '../types/AccountType';
export declare type ProvingProcessArgs = {
    accountType: AccountType;
    walletKey: web3.PublicKey;
    isExhausted: boolean;
    voucherMint: web3.PublicKey;
    packSet: web3.PublicKey;
    cardsRedeemed: number;
    cardsToRedeem: Map<number, number>;
};
export declare class ProvingProcess implements ProvingProcessArgs {
    readonly accountType: AccountType;
    readonly walletKey: web3.PublicKey;
    readonly isExhausted: boolean;
    readonly voucherMint: web3.PublicKey;
    readonly packSet: web3.PublicKey;
    readonly cardsRedeemed: number;
    readonly cardsToRedeem: Map<number, number>;
    private constructor();
    static fromArgs(args: ProvingProcessArgs): ProvingProcess;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [ProvingProcess, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<ProvingProcess>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<{
        accountType: any;
        packSet: any;
        walletKey: any;
        isExhausted: any;
        voucherMint: any;
        cardsRedeemed: any;
        cardsToRedeem: any;
    }>;
    static deserialize(buf: Buffer, offset?: number): [ProvingProcess, number];
    serialize(): [Buffer, number];
    static byteSize(args: ProvingProcessArgs): number;
    static getMinimumBalanceForRentExemption(args: ProvingProcessArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        accountType: string;
        walletKey: string;
        isExhausted: boolean;
        voucherMint: string;
        packSet: string;
        cardsRedeemed: number;
        cardsToRedeem: Map<number, number>;
    };
}
export declare const provingProcessBeet: beet.FixableBeetStruct<ProvingProcess, ProvingProcessArgs>;
